'use strict';

var backendPluginApi = require('@backstage/backend-plugin-api');
var pluginEventsNode = require('@backstage/plugin-events-node');
var GithubEventRouter = require('./cjs/GithubEventRouter-DynNUSpO.cjs.js');
var alpha = require('@backstage/plugin-events-node/alpha');
require('@octokit/webhooks-methods');

const eventsModuleGithubEventRouter = backendPluginApi.createBackendModule({
  pluginId: "events",
  moduleId: "github-event-router",
  register(env) {
    env.registerInit({
      deps: {
        events: pluginEventsNode.eventsServiceRef
      },
      async init({ events }) {
        const eventRouter = new GithubEventRouter.GithubEventRouter({ events });
        await eventRouter.subscribe();
      }
    });
  }
});

const eventsModuleGithubWebhook = backendPluginApi.createBackendModule({
  pluginId: "events",
  moduleId: "github-webhook",
  register(env) {
    env.registerInit({
      deps: {
        config: backendPluginApi.coreServices.rootConfig,
        events: alpha.eventsExtensionPoint
      },
      async init({ config, events }) {
        events.addHttpPostIngress({
          topic: "github",
          validator: GithubEventRouter.createGithubSignatureValidator(config)
        });
      }
    });
  }
});

exports.eventsModuleGithubEventRouter = eventsModuleGithubEventRouter;
exports.eventsModuleGithubWebhook = eventsModuleGithubWebhook;
//# sourceMappingURL=alpha.cjs.js.map
