import { Config } from '@backstage/config';
import { RequestValidator, SubTopicEventRouter, EventsService, EventParams } from '@backstage/plugin-events-node';

/**
 * Validates that the request received is the expected GitHub request
 * using the signature received with the `x-hub-signature-256` header
 * which is based on a secret token configured at GitHub and here.
 *
 * See https://docs.github.com/en/developers/webhooks-and-events/webhooks/securing-your-webhooks
 * for more details.
 *
 * @param config - root config
 * @public
 */
declare function createGithubSignatureValidator(config: Config): RequestValidator;

/**
 * Subscribes to the generic `github` topic
 * and publishes the events under the more concrete sub-topic
 * depending on the `x-github-event` provided.
 *
 * @public
 */
declare class GithubEventRouter extends SubTopicEventRouter {
    constructor(options: {
        events: EventsService;
    });
    protected getSubscriberId(): string;
    protected determineSubTopic(params: EventParams): string | undefined;
}

export { GithubEventRouter, createGithubSignatureValidator };
